Myosin
======
.. image:: https://badge.fury.io/py/myosin.svg
    :target: https://pypi.org/project/myosin/
    :alt: PyPi Project

.. image:: https://github.com/ztnel/myosin/actions/workflows/ci.yaml/badge.svg
    :target: https://github.com/ztnel/myosin/actions/workflows/ci.yaml
    :alt: Continuous Integration Status

.. image:: https://codecov.io/gh/ztnel/myosin/branch/master/graph/badge.svg?token=G2DNQAGVIP
    :target: https://codecov.io/gh/ztnel/myosin
    :alt: Code Coverage Summary

.. image:: https://readthedocs.org/projects/myosin/badge/?version=latest
    :target: https://myosin.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status


About
-----
*Myosin* is a lightweight framework for developing state-driven software systems. *Myosin* was originally designed to address scaling problems when developing embedded control systems with bidirectional command and control capabilities.

Core Features
~~~~~~~~~~~~~
#. Easy to use and customize
#. Thread-safe Runtime Accessors
#. State-driven Subscriber Queue
#. Strictly Typed API
#. Builtin Software Fault-Tolerance
#. Built Exclusively using Python Standard Libraries

Visit the `documentation page <https://myosin.readthedocs.io>`_ to learn more.

Contributing
------------
Contributions are welcome! Please see the `issue backlog <https://github.com/ztnel/myosin/issues>`_ and `project kanban <https://github.com/ztnel/myosin/projects/1>`_ for active work items or contact me at `christian@leapsystems.online <mailto:christian@leapsystems.online>`_.

License
-------
This project is licensed under the terms of the `MIT License <LICENSE>`_
